@@ -1,23 +1,30 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratetextinstance.h"
 #include "core/textautogeneratetextplugin.h"
+#include "textautogeneratetextcore_memory_debug.h"
 
 using namespace TextAutoGenerateText;
 TextAutoGenerateTextInstance::TextAutoGenerateTextInstance() = default;
 
 TextAutoGenerateTextInstance::~TextAutoGenerateTextInstance()
 {
+    qCDebug(TEXTAUTOGENERATETEXT_CORE_MEMORY_LOG) << " TextAutoGenerateTextInstance::~TextAutoGenerateTextInstance()" << this;
+    // if (mPlugin) {
     // mPlugin->deleteLater();
     // mPlugin = nullptr;
+    // }
 }
 
 QString TextAutoGenerateTextInstance::displayName() const
 {
-    return mPlugin->displayName();
+    if (mPlugin) {
+        return mPlugin->displayName();
+    }
+    return {};
 }
 
 QString TextAutoGenerateTextInstance::pluginName() const
