@@ -1,17 +1,17 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "ollamamodelavailblesearchwidgettest.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "modelsmanager/ollamamodelavailablesearchwidget.h"
-#include "modelsmanager/ollamamodelsinfoscategoriescombobox.h"
+#include "ollamacommonmodelsinfoscategoriescombobox.h"
 #include <QHBoxLayout>
 #include <QLineEdit>
 #include <QSignalSpy>
 #include <QTest>
+using namespace Qt::Literals::StringLiterals;
 QTEST_MAIN(OllamaModelAvailbleSearchWidgetTest)
 OllamaModelAvailbleSearchWidgetTest::OllamaModelAvailbleSearchWidgetTest(QObject *parent)
     : QObject{parent}
@@ -20,7 +20,7 @@ OllamaModelAvailbleSearchWidgetTest::OllamaModelAvailbleSearchWidgetTest(QObject
 
 void OllamaModelAvailbleSearchWidgetTest::shouldHaveDefaultValues()
 {
-    OllamaModelAvailableSearchWidget w;
+    const OllamaModelAvailableSearchWidget w;
     auto mainLayout = w.findChild<QHBoxLayout *>(u"mainlayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
@@ -30,13 +30,13 @@ void OllamaModelAvailbleSearchWidgetTest::shouldHaveDefaultValues()
     QVERIFY(mSearchLineEdit->text().isEmpty());
     QVERIFY(!mSearchLineEdit->placeholderText().isEmpty());
 
-    auto mCategoriesComboBox = w.findChild<OllamaModelsInfosCategoriesComboBox *>(u"mCategoriesComboBox"_s);
+    auto mCategoriesComboBox = w.findChild<OllamaCommonModelsInfosCategoriesComboBox *>(u"mCategoriesComboBox"_s);
     QVERIFY(mCategoriesComboBox);
 }
 
 void OllamaModelAvailbleSearchWidgetTest::shouldEmitSearchText()
 {
-    OllamaModelAvailableSearchWidget w;
+    const OllamaModelAvailableSearchWidget w;
     QSignalSpy searchTextSpy(&w, &OllamaModelAvailableSearchWidget::searchText);
 
     auto mSearchLineEdit = w.findChild<QLineEdit *>(u"mSearchLineEdit"_s);
