@@ -17,7 +17,7 @@ OllamaSettingsTest::OllamaSettingsTest(QObject *parent)
 
 void OllamaSettingsTest::shouldHaveDefaultValues()
 {
-    OllamaSettings w;
+    const OllamaSettings w;
     QCOMPARE(w.seed(), 0);
     QCOMPARE(w.temperature(), 0.8);
 
@@ -27,8 +27,11 @@ void OllamaSettingsTest::shouldHaveDefaultValues()
     QVERIFY(w.vulkanSupport().isEmpty());
     QVERIFY(w.rocrVisibleDevice().isEmpty());
     QVERIFY(w.cudaVisibleDevice().isEmpty());
+    QVERIFY(w.hipVisibleDevice().isEmpty());
     QVERIFY(w.defaultModelPath().isEmpty());
     QCOMPARE(w.serverUrl(), QUrl(u"http://127.0.0.1:11434"_s));
+    QVERIFY(!w.expose());
+    QCOMPARE(w.ollamaExpose(), u"chrome-extension://*,moz-extension://*,safari-web-extension://*,http://0.0.0.0,http://127.0.0.1"_s);
 }
 
 void OllamaSettingsTest::shouldGenerateQProcessEnvironment()
@@ -39,15 +42,22 @@ void OllamaSettingsTest::shouldGenerateQProcessEnvironment()
         w.setRocrVisibleDevice(u"bla1"_s);
         w.setVulkanSupport(u"kde1"_s);
         w.setOverrideGfxVersion(u"kf6"_s);
-        const QStringList variables{
-            {u"CUDA_VISIBLE_DEVICES=foo1"_s, u"HSA_OVERRIDE_GFX_VERSION=kf6"_s, u"OLLAMA_VULKAN=kde1"_s, u"ROCR_VISIBLE_DEVICES=bla1"_s}};
+        const QStringList variables{{u"CUDA_VISIBLE_DEVICES=foo1"_s,
+                                     u"HSA_OVERRIDE_GFX_VERSION=kf6"_s,
+                                     u"OLLAMA_HOST=http://127.0.0.1:11434"_s,
+                                     u"OLLAMA_ORIGINS=http://127.0.0.1:11434"_s,
+                                     u"OLLAMA_VULKAN=kde1"_s,
+                                     u"ROCR_VISIBLE_DEVICES=bla1"_s}};
         QCOMPARE(w.processEnvironment().toStringList(), variables);
     }
     {
         OllamaSettings w;
         w.setRocrVisibleDevice(u"bla1"_s);
         w.setOverrideGfxVersion(u"kf6"_s);
-        const QStringList variables{{u"HSA_OVERRIDE_GFX_VERSION=kf6"_s, u"ROCR_VISIBLE_DEVICES=bla1"_s}};
+        const QStringList variables{{u"HSA_OVERRIDE_GFX_VERSION=kf6"_s,
+                                     u"OLLAMA_HOST=http://127.0.0.1:11434"_s,
+                                     u"OLLAMA_ORIGINS=http://127.0.0.1:11434"_s,
+                                     u"ROCR_VISIBLE_DEVICES=bla1"_s}};
         QCOMPARE(w.processEnvironment().toStringList(), variables);
     }
 }
