@@ -1,15 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "ollamamodelavailableinfowidget.h"
 #include "autogeneratetext_ollama_debug.h"
 
+#include "ollamacommonmodelavailableinfosmodel.h"
+#include "ollamacommonnetworkurlbutton.h"
 #include "ollamamanager.h"
-#include "ollamamodelavailableinfosmodel.h"
 #include "ollamamodeldownloadwidget.h"
-#include "ollamanetworkurlbutton.h"
 #include "widgets/common/textautogenerateflowlayout.h"
 #include <KLocalizedString>
 #include <QDesktopServices>
@@ -23,7 +23,7 @@ OllamaModelAvailableInfoWidget::OllamaModelAvailableInfoWidget(OllamaManager *ma
     , mMainLayout(new QVBoxLayout(this))
     , mModelName(new QLabel(this))
     , mOllamaManager(manager)
-    , mNetworkUrlButton(new OllamaNetworkUrlButton(this))
+    , mNetworkUrlButton(new OllamaCommonNetworkUrlButton(this))
 {
     mMainLayout->setObjectName(u"mainlayout"_s);
     mMainLayout->setContentsMargins({});
@@ -47,18 +47,18 @@ void OllamaModelAvailableInfoWidget::generateWidget(const QModelIndex &index)
         mMainLayout->removeWidget(mInfoWidget);
         mInfoWidget->deleteLater();
     }
-    const QString modelName = index.data(OllamaModelAvailableInfosModel::ModelName).toString();
+    const QString modelName = index.data(OllamaCommonModelAvailableInfosModel::ModelName).toString();
     mModelName->setText(modelName);
 
-    const QString url = index.data(OllamaModelAvailableInfosModel::Url).toString();
-    mNetworkUrlButton->setModelUrl(url);
+    const QString url = index.data(OllamaCommonModelAvailableInfosModel::Url).toString();
+    mNetworkUrlButton->setUrl(url);
 
     mInfoWidget = new QWidget(this);
     auto infoLayout = new QVBoxLayout(mInfoWidget);
 
     auto languagesGroupBox = new QGroupBox(i18n("Languages Supported"), mInfoWidget);
     auto languagesGroupBoxLayout = new TextAutoGenerateText::TextAutoGenerateFlowLayout(languagesGroupBox);
-    const QStringList languages = index.data(OllamaModelAvailableInfosModel::Languages).toStringList();
+    const QStringList languages = index.data(OllamaCommonModelAvailableInfosModel::Languages).toStringList();
     for (const auto &l : languages) {
         const QLocale locale(l);
         if (locale.language() == QLocale::Language::C) {
@@ -73,7 +73,8 @@ void OllamaModelAvailableInfoWidget::generateWidget(const QModelIndex &index)
 
     infoLayout->addWidget(downloadModelGroupBox);
     auto downloadGroupBoxLayout = new QVBoxLayout(downloadModelGroupBox);
-    const QList<OllamaModelAvailableInfo::ModelTag> tags = index.data(OllamaModelAvailableInfosModel::Tags).value<QList<OllamaModelAvailableInfo::ModelTag>>();
+    const QList<OllamaCommonModelAvailableInfo::ModelTag> tags =
+        index.data(OllamaCommonModelAvailableInfosModel::Tags).value<QList<OllamaCommonModelAvailableInfo::ModelTag>>();
     for (const auto &t : tags) {
         const bool alreadyInstalled = mOllamaManager->isAlreadyInstalled(u"%1:%2"_s.arg(modelName, t.tag));
         auto downLoadWidget = new OllamaModelDownloadWidget(t.tag, t.size, alreadyInstalled, mInfoWidget);
