@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,12 +7,13 @@
 
 #include "autogeneratetext_ollama_debug.h"
 #include "modelsmanager/ollamamodeldownloadfromnamedialog.h"
-#include "ollamamodelavailableinfosmodel.h"
-#include "ollamamodelavailableinfossortproxymodel.h"
+#include "ollamacommonmodelavailableinfosdelegate.h"
+#include "ollamacommonmodelavailableinfosmodel.h"
+#include "ollamacommonmodelavailableinfossortproxymodel.h"
 #include "ollamamodelavailableinfowidget.h"
-#include "ollamamodelavailablelistview.h"
 #include "ollamamodelavailablesearchwidget.h"
 #include "ollamamodeldownloadprogresswidget.h"
+#include "widgets/availablemodel/textautogeneratemodelavailablelistview.h"
 #include <KMessageBox>
 #include <QScrollArea>
 #include <QSplitter>
@@ -23,14 +24,15 @@ using namespace Qt::Literals::StringLiterals;
 OllamaModelAvailableWidget::OllamaModelAvailableWidget(OllamaManager *manager, QWidget *parent)
     : QWidget{parent}
     , mSearchWidget(new OllamaModelAvailableSearchWidget(this))
-    , mListView(new OllamaModelAvailableListView(this))
+    , mListView(new TextAutoGenerateText::TextAutoGenerateModelAvailableListView(this))
     , mInfoWidget(new OllamaModelAvailableInfoWidget(manager, this))
-    , mProxyModel(new OllamaModelAvailableInfosSortProxyModel(this))
+    , mProxyModel(new OllamaCommonModelAvailableInfosSortProxyModel(this))
     , mOllamaModelDownloadProgressWidget(new OllamaModelDownloadProgressWidget(manager, this))
     , mStackedWidget(new QStackedWidget(this))
-    , mAvailableInfosModel(new OllamaModelAvailableInfosModel(this))
+    , mAvailableInfosModel(new OllamaCommonModelAvailableInfosModel(this))
     , mScrollArea(new QScrollArea(this))
 {
+    mListView->setItemDelegate(new OllamaCommonModelAvailableInfosDelegate(mListView));
     auto splitter = new QSplitter(this);
     splitter->setOrientation(Qt::Horizontal);
     splitter->setObjectName(u"splitter"_s);
@@ -65,15 +67,15 @@ OllamaModelAvailableWidget::OllamaModelAvailableWidget(OllamaManager *manager, Q
 
     mProxyModel->setSourceModel(mAvailableInfosModel);
     mListView->setModel(mProxyModel);
-    connect(mSearchWidget, &OllamaModelAvailableSearchWidget::searchText, mProxyModel, &OllamaModelAvailableInfosSortProxyModel::setFilterFixedString);
-    connect(mSearchWidget, &OllamaModelAvailableSearchWidget::categoriesChanged, mProxyModel, &OllamaModelAvailableInfosSortProxyModel::setCategories);
-    connect(mListView, &OllamaModelAvailableListView::pressed, this, &OllamaModelAvailableWidget::slotClicked);
+    connect(mSearchWidget, &OllamaModelAvailableSearchWidget::searchText, mProxyModel, &OllamaCommonModelAvailableInfosSortProxyModel::setFilterFixedString);
+    connect(mSearchWidget, &OllamaModelAvailableSearchWidget::categoriesChanged, mProxyModel, &OllamaCommonModelAvailableInfosSortProxyModel::setCategories);
+    connect(mListView, &TextAutoGenerateText::TextAutoGenerateModelAvailableListView::pressed, this, &OllamaModelAvailableWidget::slotClicked);
     connect(mSearchWidget, &OllamaModelAvailableSearchWidget::addModel, this, &OllamaModelAvailableWidget::slotAddModel);
 }
 
 OllamaModelAvailableWidget::~OllamaModelAvailableWidget() = default;
 
-void OllamaModelAvailableWidget::setAvailableInfos(const QList<OllamaModelAvailableInfo> &infos)
+void OllamaModelAvailableWidget::setAvailableInfos(const QList<OllamaCommonModelAvailableInfo> &infos)
 {
     mAvailableInfosModel->setModelInfos(infos);
 }
