@@ -11,7 +11,7 @@
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
+    const QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
     QCommandLineParser parser;
     parser.addVersionOption();
