@@ -24,7 +24,7 @@ TextToSpeechConfigGui::~TextToSpeechConfigGui() = default;
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
+    const QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
     QCommandLineParser parser;
     parser.addVersionOption();
