@@ -50,7 +50,7 @@ void TextToSpeechGui::slotTextToSpeech()
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
+    const QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
     QCommandLineParser parser;
     parser.addVersionOption();
